colour.temperature — Colour 0.3.0 documentation

# Source code for colour.temperature

    #!/usr/bin/env python
    # -*- coding: utf-8 -*-

    from __future__ import absolute_import

    from .cct import CCT_TO_UV_METHODS, UV_TO_CCT_METHODS
    from .cct import CCT_to_uv, CCT_to_uv_ohno2013, CCT_to_uv_robertson1968
    from .cct import uv_to_CCT, uv_to_CCT_ohno2013, uv_to_CCT_robertson1968
    from .cct import CCT_TO_XY_METHODS, XY_TO_CCT_METHODS
    from .cct import CCT_to_xy, CCT_to_xy_kang2002, CCT_to_xy_illuminant_D
    from .cct import xy_to_CCT, xy_to_CCT_mccamy1992, xy_to_CCT_hernandez1999

    __all__ = ['CCT_TO_UV_METHODS', 'UV_TO_CCT_METHODS',
               'CCT_to_uv', 'CCT_to_uv_ohno2013', 'CCT_to_uv_robertson1968',
               'uv_to_CCT', 'uv_to_CCT_ohno2013', 'uv_to_CCT_robertson1968',
               'CCT_TO_XY_METHODS', 'XY_TO_CCT_METHODS',
               'CCT_to_xy', 'CCT_to_xy_kang2002', 'CCT_to_xy_illuminant_D',
               'xy_to_CCT', 'xy_to_CCT_mccamy1992', 'xy_to_CCT_hernandez1999']